@@ -11,6 +11,9 @@ sub import {
 
   feature::->import('signatures');
   warnings::->unimport('experimental::signatures');
+
+  feature::->import('lexical_subs');
+  warnings::->unimport('experimental::lexical_subs');
 }
 
 1;
@@ -27,7 +30,7 @@ Evo::Default
 
 =head1 VERSION
 
-version 0.0199
+version 0.0227
 
 =head1 DESCRIPTION
 
