@@ -1,15 +1,18 @@
 package Evo::Loop::Role::Postpone;
-use Evo '-Role *';
+use Evo '-Class *, -new';
 
 requires qw(zone_cb);
 
-has data_postpone => default => sub { [] };
+has postpone_queue => default => sub { [] };
 
-sub postpone_count($self) : Role { $self->data_postpone->@* }
-sub postpone($self, $fn) : Role { push $self->data_postpone->@*, $self->zone_cb($fn); }
+sub postpone_count($self) { $self->postpone_queue->@* }
 
-sub postpone_process($self) : Role {
-  my $postpone = $self->data_postpone;
+sub postpone ($self, $fn) {
+  push $self->postpone_queue->@*, $self->zone_cb($fn);
+}
+
+sub postpone_process($self) {
+  my $postpone = $self->postpone_queue;
   shift(@$postpone)->() while @$postpone;
 }
 
@@ -27,7 +30,7 @@ Evo::Loop::Role::Postpone
 
 =head1 VERSION
 
-version 0.0199
+version 0.0227
 
 =head1 AUTHOR
 
