@@ -1,16 +1,16 @@
 package Evo::Net::Srv;
-use Evo '-Comp *';
+use Evo '-Class *';
 
-with ':Role', -Ee;
+with '::Role', -Ee;
 
 sub ee_events {qw(srv_accept srv_error)}
 
-sub srv_handle_accept($self, $sock) : Override {
+sub srv_handle_accept ($self, $sock) : Over {
   $self->emit(srv_accept => $sock);
   $sock;
 }
 
-sub srv_handle_error($self, $conn, $err) : Override {
+sub srv_handle_error ($self, $conn, $err) : Over {
   Evo::Net::Srv::Role::srv_handle_error($self, $conn, $err);
   $self->emit(srv_error => $conn, $err);
 }
@@ -29,18 +29,18 @@ Evo::Net::Srv
 
 =head1 VERSION
 
-version 0.0199
+version 0.0227
 
 =head1 SYNOPSYS
 
   use Evo '-Net::Srv; -Loop *';
 
-  my $srv = Evo::Net::Srv::new();
+  my $srv = Evo::Net::Srv->new();
   my $listen_socket = $srv->srv_listen(ip => '*', port => 8080);
 
   $srv->on(
     srv_accept => sub($srv, $sock) {
-      my ($ip, $port) = $sock->socket_remote;
+      my ($ip, $port) = $sock->io_remote;
       say sprintf("New connection from %s[%s], [%s]", $ip, $port, scalar localtime);
     }
   );
