@@ -27,6 +27,11 @@ sub spread : prototype(&) : Export {
   $PRM = $PRM->spread(@_);
 }
 
+sub finally : prototype(&) : Export {
+  croak "Broken flow" unless $PRM;
+  $PRM = $PRM->finally(@_);
+}
+
 1;
 
 __END__
@@ -41,7 +46,7 @@ Evo::Prm
 
 =head1 VERSION
 
-version 0.0199
+version 0.0227
 
 =head1 DESCRIPTION
 
