@@ -1,15 +1,15 @@
 package Evo::Promise::Deferred;
-use Evo '-Comp *';
+use Evo '-Class *';
 
 has 'promise', required => 1, is => 'ro';
 has 'called';
 
-sub reject($self, $r) {
+sub reject ($self, $r) {
   return if $self->called;
   $self->called(1)->promise->d_reject_continue($r);
 }
 
-sub resolve($self, $v) {
+sub resolve ($self, $v) {
   return if $self->called;
   $self->called(1)->promise->d_resolve_continue($v);
 }
@@ -28,7 +28,7 @@ Evo::Promise::Deferred
 
 =head1 VERSION
 
-version 0.0199
+version 0.0227
 
 =head1 AUTHOR
 
